frequentTerms(dtm, variable = NULL, n = 25)dtm, or NULL to report most
frequent terms by document; use NA to report most frequent terms in the whole corpus.variable = NA, one matrix with columns Global % (see below).
Else, a list of matrices, one for each level of the variable, with seven columns:specificTerms, DocumentTermMatrix