When a variable is selected, the operation is run separately on each sub-matrix constituted
by the documents that are members of the variable level. If the term does not appear in a
level, NA is returned.
When several terms are entered, the operation is simply run several times separately.
termChisqDist, DocumentTermMatrix, restrictTermsDlg,
termsDictionary, freqTermsDlg